@@ -74,7 +74,6 @@ void SMB_Print_Pkt(FILE fd, RFCNB_Pkt *pkt, BOOL command, int Offset, int Len)
 
     /* Print the other bits in the header                  */
 
-
     /* etc                                                 */
 
 }
@@ -223,7 +222,6 @@ int SMB_Figure_Protocol(const char *dialects[], int prot_index)
 
 }
 
-
 /* Negotiate the protocol we will use from the list passed in Prots       */
 /* we return the index of the accepted protocol in NegProt, -1 indicates  */
 /* none acceptible, and our return value is 0 if ok, <0 if problems       */
@@ -303,7 +301,6 @@ int SMB_Negotiate(SMB_Handle_Type Con_Handle, const char *Prots[])
 
     if (RFCNB_Send(Con_Handle -> Trans_Connect, pkt, pkt_len) < 0) {
 
-
 #ifdef DEBUG
         fprintf(stderr, "Error sending negotiate protocol\n");
 #endif
@@ -770,7 +767,7 @@ int SMB_Get_Last_SMB_Err()
 
 static const char *SMBlib_Error_Messages[] = {
 
-    "Request completed sucessfully.",
+    "Request completed successfully.",
     "Server returned a non-zero SMB Error Class and Code.",
     "A lower layer protocol error occurred.",
     "Function not yet implemented.",
